==> ExternalSiteCatalog-1.1.2.tgz: ExternalSiteCatalog/Extensions/MaintenanceToolbox.py <==
# -*- coding: utf-8 -*-
## Used to install ExternalSiteCatalog content
## Copyright (C)2005 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""
Main external methods that are part of our proposed scripts collection
"""
__version__ = "$Revision: 1.7 $"
# $Source: /cvsroot/ingeniweb/ExternalSiteCatalog/Extensions/MaintenanceToolbox.py,v $
# $Id: MaintenanceToolbox.py,v 1.7 2006/05/31 15:19:32 roeder Exp $
__docformat__ = 'restructuredtext'

from StringIO import StringIO
import time
from DateTime import DateTime

#from Products.ExternalMethod.ExternalMethod import ExternalMethod
from Products.CMFCore.utils import getToolByName
from Acquisition import aq_parent

# Timeit function stolen from ATContentTypes 1.0/tool/migration.py
def timeit(data=None):
    """Measure real time and cpu time of an event

    returns real time, cpu time as tuple
    """
    if data is None:
        return time.time(), time.clock()
    else:
        return time.time() - data[0], time.clock() - data[1]

# #########################################
# 1/ crawlExternalSite - Crawl external sites
# #########################################

def crawlExternalSite(self, force, site, pending_callback, time_limit, max_pages, charset, login, password):
    """Crawl external sites"""
    portal_externalcatalog = getToolByName(self, 'portal_externalcatalog')
    return portal_externalcatalog.indexSite(force, site, pending_callback, int(time_limit), int(max_pages), charset, login, password)

==> ExternalSiteCatalog-1.2.0.tgz: ExternalSiteCatalog/Extensions/MaintenanceToolbox.py <==
# -*- coding: utf-8 -*-
## Used to install ExternalSiteCatalog content
## Copyright (C)2005 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""
Main external methods that are part of our proposed scripts collection
"""
__version__ = "$Revision: 1.8 $"
# $Source: /cvsroot/ingeniweb/ExternalSiteCatalog/Extensions/MaintenanceToolbox.py,v $
# $Id: MaintenanceToolbox.py,v 1.8 2006/11/30 17:12:55 roeder Exp $
__docformat__ = 'restructuredtext'

from StringIO import StringIO
import time
from DateTime import DateTime

#from Products.ExternalMethod.ExternalMethod import ExternalMethod
from Products.CMFCore.utils import getToolByName
from Acquisition import aq_parent

# Timeit function stolen from ATContentTypes 1.0/tool/migration.py
def timeit(data=None):
    """Measure real time and cpu time of an event

    returns real time, cpu time as tuple
    """
    if data is None:
        return time.time(), time.clock()
    else:
        return time.time() - data[0], time.clock() - data[1]

# #########################################
# 1/ crawlExternalSite - Crawl external sites
# #########################################

def crawlExternalSite(self, force, site, pending_callback, time_limit, max_pages, charset, login, password, path_incl_regexps, path_excl_regexps):
    """Crawl external sites"""
    portal_externalcatalog = getToolByName(self, 'portal_externalcatalog')
    return portal_externalcatalog.indexSite(force, site, pending_callback, int(time_limit), int(max_pages), charset, login, password, path_incl_regexps, path_excl_regexps)
